import express from 'express';
import { Logger } from 'winston';
import { CatalogClient } from '@backstage/catalog-client';
import * as graphql_modules from 'graphql-modules';
import { Module } from 'graphql-modules';
import { Entity, CompoundEntityRef } from '@backstage/catalog-model';
import DataLoader from 'dataloader';
import * as _envelop_core from '@envelop/core';

declare type EntityRef = string | CompoundEntityRef;
declare type EntityLoader = DataLoader<EntityRef, Entity>;

interface createGraphQLAppOptions {
    entityLoaderCreator: () => EntityLoader;
    modules: Module[];
}
declare function createGraphQLApp({ modules, entityLoaderCreator }: createGraphQLAppOptions): {
    run: _envelop_core.GetEnvelopedFn<{
        [x: string]: any;
        [x: number]: any;
        [x: symbol]: any;
    }>;
    application: graphql_modules.Application;
};

interface RouterOptions {
    logger: Logger;
    catalog: CatalogClient;
    entityLoaderCreator?: () => EntityLoader;
    modules?: Module[];
}

declare function createRouter(options: RouterOptions): Promise<express.Router>;

export { EntityLoader, RouterOptions, createGraphQLApp, createGraphQLAppOptions, createRouter };
